@@ -9,7 +9,7 @@ use Class::Utils qw(set_params_pub);
 use Unicode::Block::Item;
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Constructor.
 sub new {
@@ -168,13 +168,18 @@ Constructor.
 L<Class::Utils>,
 L<Unicode::Block::Item>.
 
+=head1 SEE ALSO
+
+L<Unicode::Block::Ascii>,
+L<Unicode::Block::List>.
+
 =head1 REPOSITORY
 
 L<https://github.com/tupinek/Unicode-Block>
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
@@ -184,6 +189,6 @@ BSD license.
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
